@@ -1,6 +1,12 @@
 from behave import when
 
 
+@when(
+    'the argument --from-commit-message is provided as "{from_commit_message}".')
+def set_from_commit_message(context, from_commit_message):
+    context.arguments += " --from-commit-message " + from_commit_message + " "
+
+
 @when('the argument --from-commit-hash is provided as "{from_commit_hash}".')
 def set_from_commit_hash(context, from_commit_hash):
     context.arguments += " --from-commit-hash " + from_commit_hash + " "
